function [B,A,soll,ist] = mn_barkfilter(ordr)

% mn_barkfilter             - calculates a cell with filter coefficients for critical bands (unit: bark)
% 
% [B,A,soll,ist] = mn_barkfilter(ordr)
%
%   B,A: cells with filter coeffs
%   soll: spectrum of ideal filter
%   ist:  spectrum of calculated filter
%
% Try that: 
%      [b,a,soll,ist]=mn_createfilter([400,10]);
%      mn_plot(20*log10(abs(soll)),'o',20*log10(abs(ist)),'r');
%
% 2.10.2001
% Piotr Majdak (piotr@majdak.com)
% Markus Noisternig (markus@noisternig.com)



    % get the bark-scale
x=zeros(256,1);
[x,f]=mn_f2bark(x,44100);
clear x;
f(2:end+1)=f;
f(1)=20;
    % create filter matrices
soll=zeros(4410,length(f)-1);
ord=round(ordr(1):(ordr(2)-ordr(1))/(length(f)-1):ordr(2));
B=cell(length(f)-2,1);
A=cell(length(f)-2,1);

h = waitbar(0,'calculating bark filters...');    
for ii=1:length(f)-1
    band(1)=0;
    band(2)=f(ii)/22050*0.8;
    band(3)=f(ii)/22050;
    band(4)=f(ii+1)/22050;
    band(5)=f(ii+1)/22050*1.2;    
    if band(5)>=1
        band(5)=0.99;
    end
    band(6)=1;
    amp=[0 0 1 1 0 0];
    %disp(ord(ii));
    [b,a]=firls(ord(ii),band,amp);   
    ist(1:2205,ii)=freqz(b,a,2205);
    ist(2206:4410,ii)=flipud(ist(1:2205,ii));
    soll(round(f(ii)/10):round(f(ii+1)/10),ii)=1;
    B(ii)={b};
    A(ii)={a};
    waitbar(ii/(length(f)-1), h);
end
close(h);
