function res_m = mn_error(user_m, ref_m, mode, fs)

% mn_error             - calculates error of a matrix related to a reference matrix
%
% res_m = mn_error(user_m, ref_m, mode)
%
% Berechnet den Fehler von Vektoren der Matrix user_m in Bezug auf
% die jeweiligen Vektoren dem Matrix ref_m.
% Das Ergebnis res_m wird je nach mode komplex oder skalar geliefert.
% 
% Eingabeparameter:
% user_m: Matrix mit Istwerten
% ref_m:  Matrix mit Sollwerten, mu dieselbe Gre wie user_m haben
% mode:   'rel'   Relativer Fehler:       rF = (|ist|-|soll|)/|soll|  
%         '%'     Relativer Fehler:       pF: = 100% * rF  
%         'log'   Relativer Fehler:       lF: = LOG10(rF)            
%         'dB'    Relativer Fehler:       dB: = 20dB * LOG10(rF)
%         'ratio' Quotient-Fehler:        rF = |ist|/|soll|
%         'abs'   Absoluter Fehler:       aF = (|ist|-|soll|)
%         'cpx'   Komplexer Fehler:       cF = (ist-soll)
%         'cpxa'  Kompl.abs.Fehler:       caF = |(ist-soll)|
%         'cpxr'  Kompl.rel.Fehler:       crF = (ist-soll)/soll
%         'cpxra' Kompl.rel.Fehler (abs): craF= |(ist-soll)/soll|
%
% Ausgabeparameter:
% res_m:   Fehlermatrix
%
% 11.9.2001
% Piotr Majdak (piotr@majdak.com)
% Markus Noisternig (markus@noisternig.com)


if strcmp(mode,'rel') == 1
    disp('Relativer Fehler: rF = (|ist|-|soll|)/|soll|');
    res_m=(abs(user_m) - abs(ref_m))./ abs(ref_m);  % calc the relativ error
    disp('Linear: = rF');
end
if strcmp(mode,'%')==1
    disp('Relativer Fehler: rF = (|ist|-|soll|)/|soll|');
    res_m=(abs(user_m) - abs(ref_m)) ./ abs(ref_m);  % calc the relativ error
    disp('Prozentuell: = 100% * rF');
    res_m = 100*(res_m);
end
if strcmp(mode,'log') == 1
    disp('Relativer Fehler: rF = (|ist|-|soll|)/|soll|');
    res_m=(abs(user_m) - abs(ref_m)) ./ abs(ref_m);  % calc the relativ error
    disp('Logarithmisch: = LOG10(rF)');
    res_m = log10(abs(res_m));
end
if strcmp(mode,'dB') == 1
    disp('Relativer Fehler: rF = (|ist|-|soll|)/|soll|');
    res_m=(abs(user_m) - abs(ref_m)) ./ abs(ref_m);  % calc the relativ error
    disp('dB: = 20dB * LOG10(rF)');
    res_m = 20*log10(abs(res_m));   
end
if strcmp(mode,'ratio') == 1
    disp('Verhltnis: rF = |ist|/|soll|');
    res_m=(abs(user_m))./ abs(ref_m);  % calc the ratio
end
if strcmp(mode,'abs') == 1
    disp('Absoluter Fehler: aF = (|ist|-|soll|)');
    res_m=(abs(user_m) - abs(ref_m));  % calc the relativ error
end
if strcmp(mode,'cpx') == 1
    disp('Komplexer Fehler: cF = (ist-soll)');
    res_m=((user_m) - (ref_m));  % calc the complex difference
end
if strcmp(mode,'cpxa') == 1
    disp('Komplexer Fehler, absolut: caF = |(ist-soll)|');
    res_m=abs((user_m) - (ref_m));  % calc the complex difference
end
if strcmp(mode,'cpxr') == 1
    disp('Kompl. rel. Fehler: crF = (ist-soll)/soll');
    res_m=((user_m) - (ref_m))./abs(ref_m);  % calc the complex error
end
if strcmp(mode,'cpxra') == 1
    disp('Kompl. rel. Fehler (absolut): craF = |(ist-soll)/soll|');
    res_m=abs((user_m) - (ref_m))./abs(ref_m);  % calc the complex error
end
     