function [out,f]=mn_f2bark(matr, sr)

% f2bark            - Transform each vector of matrix from frequency to bark domain
%
% [out,f] = mn_f2bark(vect, sr)
%
% The matrix matr (must be in frequency domain) will be transform to 
% a vector of one-sided spectra in the bark domain. 
%
% Input:
%  matr:   spectrum to convert
%  sr:     sampling rate (frequency of the last bin)
%
% Output:
%  out:    matrix containing vectors of one-sided spectra in bark domain
%    f:    frequency scale of bark-transformation
%
% Piotr Majdak (piotr@majdak.com)
% Markus Noisternig (markus@noisternig.com)
% 13.2.2002

    % generate the bark scale
bark = 1:24;
f=((bark+0.53).*1960)./(26.28-bark);     % sttzstellen in Hz
fh(1) = 0;
fh(2:25)=f(1:24); % hilfsvektor, f um 1 versetzt

    % get the sizes of vect
s=size(matr);
len=s(1);
ss=s(2);
    % create a wait bar
h = waitbar(0,'f2bark - working...');
    % Transform a vector from frequency to bark domain
fs=fh/sr*len;
fs(1)=1;
for xx=1:ss
    for ii=1:24
        out(ii,xx)=mean(matr(ceil(fs(ii))+1:ceil(fs(ii+1))+1,xx));
    end
    waitbar(xx/ss);
end
close(h);