function res = mn_findzero(matr,near,err)

% mn_findzero      - find the zero-cross of each vector in matrix near to the 'near'
%
% res = mn_findzero(matr,near [,err])
%
% Input parameters:
%
%   matr:    matrix with data vectors
%   near:    find the zero-cross near to 'near'
%   err:     error value, will be set when the zero-cross couldn't be found
%
% Output parameter:
%   
%   res:     result
%
% Piotr Majdak (piotr@majdak.com)
% Markus Noisternig (markus@noisternig.com)
% 8.10.2001

if ~ismember('err', who)
   err=NaN;
end
    % interpolate for all vectors
for ii=1:size(matr,2)
        % shift the rows left by one
    mm2=matr(:,ii);
    mm2(2:end+1)=matr(:,ii);
    mm3=matr(:,ii);
    mm3(end+1)=matr(end,ii);
        % xor original with moved matrix -> results are ones on zero-crossing points
    xorm=xor(abs(sign(mm2)+1),abs(sign(mm3)+1)); 
        % find real zeros 
    zer = mm3==0;
        % combine zero-cross and real zeros to a vector
    com=or(xorm,zer);
    % create vector w/ all zero-crossings
    i=find(com);
    if isempty(i)
            % zero-cross not found in this row -> set to NaN    
        res(ii)=err;
    else
            % zero-cross or zero found
        [a,zeroidx]=min(abs(i-near-0.5));   % look for the zero-cross/zero nearest to 'near'
        %keyboard;
            % differ zero or zero-cross
        if zer(i(zeroidx))==1
                % real zero found
            res(ii)=i(zeroidx);
        else
                % zero-cross found -> look for a zero cross on the other side of near
            if or(isempty(find(i==2*near+1-i(zeroidx))), length(i)==1)
                % no mirrored zero-cross found -> interpolate (linear) and save as result
                %disp('no');
                y1=matr(i(zeroidx)-1,ii);
                y2=matr(i(zeroidx),ii);       
                res(ii)=i(zeroidx)-1+y1/(y1-y2);
                %keyboard;
            else
                % a mirrored zero-cross found -> must check both of them
                    % first zero-cross
                %disp('yes');
                y1=matr(i(zeroidx)-1,ii);
                y2=matr(i(zeroidx),ii);       
                first=i(zeroidx)-1+y1/(y1-y2);
                    % mirrored zero-cross
                zeroidx=find(i==2*near+1-i(zeroidx));
                y1=matr(i(zeroidx)-1,ii);
                y2=matr(i(zeroidx),ii);       
                mirrored=i(zeroidx)-1+y1/(y1-y2);
                %keyboard;
                if abs(first-near)<abs(mirrored-near)
                    res(ii)=first;      % first zero-cross is more near to 'near'
                else
                    res(ii)=mirrored;   % mirrored zero-cross is more near to 'near'
                end
                %keyboard;
            end
        end
    end
end
    % that's all...