function [out,grpdel] = mn_grpdelay(inp, B, A)

% mn_createfilter             - calculates group delay using energy emphasis method 
% 
% [out,grpdel] = mn_grpdelay(inp, B, A)
%
%   Calculates the group delay of each vector in matrix inp
%   The filter coefficients A and B are cells containing a filter for each wanted frequency
%   Setting A and B you can change the output resolution of the group delay matrix
%   mn_barkfilter outputs A and B for resolution of critical bands, for example.
%
%   inp:    impulse response (matrices allowed)
%   A:      filter coeffs A
%   B:      filter coeffs B (see mn_barkfilter)
%   
%   out:    filtered input (only the last imp. resp) - (samplenr,f_filter)
%   grpdel: vector (matrix) with group delay (in samples) 
%
%
% 15.10.2001
% Piotr Majdak (piotr@majdak.com)
% Markus Noisternig (markus@noisternig.com)


    % settings
taps=4410;   % set length of zero tapped imp. resp.

    % zero padding of imp resp 
rest=taps-size(inp,1);
in=zeros(taps,size(inp,2));
in(rest/2+1:rest/2+size(inp,1),:)=inp;    % in: zero padded imp. response

    % create filter matrices
%out=zeros(size(in,1),size(inp,2),size(B,1));

    % filter & calc grpdelay
h = waitbar(0,'calculating each impulse response...');        
for ii2=1:size(inp,2)   % for each vector
    in2=in(:,ii2);
    for ii=1:size(B,1)  % for each frequency
        b=deal(B{ii});
        a=deal(A{ii});
        out2(:,ii)=filtfilt(b,a,in2);
        grpdel2(ii)=sum((0:1:size(out2(:,ii),1)-1)'.*out2(:,ii).^2)./sum(out2(:,ii).^2); 
    end
    waitbar(ii2/size(inp,2), h);
    grpdel(:,ii2)=grpdel2';
    out=out2;
end
close(h);
grpdel=grpdel-2077;
