function sp = mn_ir2tf(imp, fade, len)

% mn_ir2tf          - Calculate a transfer function from impulse response
%
% sp = mn_ir2tf(imp, fade [,len])
%
% Rechnet eine Matrix von Impulsantworten in eine Matrix von Spektren um
% Der letzte Teil der Impulsantworten von Lnge fade wird mittel Hann-Fenster 
% ausgeblendet. Die Impulsantwort wird vor der FFT auf die Lnge len erweitert.
% 
% Eingabeparameter:
% imp:  Matrix mit Impulsantworten
% fade: Die Anzahl der taps zum ausblenden, fade=0 fr nichts ausblenden
% len:  Anzahl der bins in der FFT, Impulsantwort wird auf diese Lnge erweitert, optional
%
% Ausgabeparameter:
% sp:   Matrix mit den berechneten Spektren
%
% 11.9.2001
% Piotr Majdak (piotr@majdak.com)
% Markus Noisternig (markus@noisternig.com)

s=size(imp);    % get vector size of imp
ss=s(1);        % get the len of imp resp.
nn=s(2);        % get the number of imp. resps.
if ~exist('len')      % calc the len of imp resp.
    len = ss;
end
    % create new vectors
if fade > 0
    han=hann(2*fade);    % hann-window
end
sp=zeros(len,nn);    % spectrum matrix
a=zeros(len,1);      % temp vector
    % create a wait bar
h = waitbar(0,'impresp2spect - working...');
    % main loop
for x = 1 : nn
    a(1:ss)=imp(:,x);     % get the imp resp
    if fade > 0 
        a(ss-fade:ss)= a(ss-fade:ss).* han(fade:2*fade);   % fade out
    end
    sp(:,x)=fft(a);  % transform and save 
    %sp(:,x)=a;
    waitbar(x/nn);
end
close(h);