function res_m = mn_normvect(user_m, ref_m, len)

% mn_normvect           - Normalise vectors of a matrix to the sum of energy of each reference vector
% 
% res_m = mn_normvect(user_m, ref_m [,len])
%
% Normalisiert die Vektoren in Matrix user_m auf den Energiegehalt der jeweiligen
% Vektoren in Matrix ref_m. Beim Ergebnis gilt also:
% ENERGY(user_m(:,x)) = ENERGY(ref_m(:,x)), x=alle Zeilen von ref_m
% 
% Eingabeparameter:
% user_m: Matrix, die normiert werden sollte
% ref_m:  Matrix, die als Referenz dient, mu dieselbe Gre wie user_m haben
% len:    Lnge der Vektoren, die bei der Berechnung bercksichtigt werden soll, optional
%
% Ausgabeparameter:
% res_m:   Normierte Matrix, die Vektoren haben die Lnge len
%
% 13.9.2001
% Piotr Majdak (piotr@majdak.com)
% Markus Noisternig (markus@noisternig.com)


s=size(user_m);    % get vector size of matrix
ss=s(1);        % get the len of imp resp.
nn=s(2);        % get the number of imp. resps.
if ~exist('len')
    [len,s]=size(user_m);
else
    if len=='all'
        [len,s]=size(user_m);   % rckwrtskompatibilitt... :-(
    end
end
    % create new vectors
res_m=zeros(len,nn);    % spectrum matrix
    % main loop
for x = 1 : nn
    Eu = sum((abs(user_m(1:len,x))).^2);      % calc the energy of the the user vector
    Er = sum((abs(ref_m(1:len,x))).^2);      % calc the energy of the the ref vector
    res_m(:,x) = user_m(1:len,x) * ((Er/Eu)^0.5);  % normalize
    disp(x);
end
