
function mn_polar(varargin)

% mn_polar              - Interactive slideshow of matrizes using 2D-polar
%
% mn_polar([xaxisD,] matrixD [,linetypeD] [,axis] [,step])
%
% GUI zur Visualisierung von Matrizen in POLAR-Form
% Parameter:
%    matrixD: (m,n) Matrix die grafisch dargestellt werden soll
% 	      	  Form: m .. darzustellende Werte (pro Vektor)
%				    n .. verschiedene Vektoren
%
%    optionale Parameter:
%    xaxisD:    die X-Achse fr die dazugehrige matrixD
%    linetypeD: line type (siehe PLOT) fr die dazugehrige matrixD
%    step:   Skalierungsfaktor fr die step-Anzeige
%            Default: step=1
%    axis:   Vektor mit der Skalierung der Achsen in Form von [XMIN XMAX YMIN YMAX]
%            Default: auto-scaling
%
%    Es knnen bis zu 10 Matrizen gleichzeitig dargestellt werden, wobei die Reihenfolge
%    [xaxisD,] matrixD [,linetypeD] mit D=1..5 mu beibehalten werden (siehe POLAR)
% 
%    Beispiele:
%    mn_polar(y);        slide-show mit step=1, auto-scaling, entspricht: polar(y);
%
%    mn_polar(x1,y1,'b', x2,y2,'r');   slide-show mit step=1, auto-scaling, entspricht:
%                                     polar(x1,y1,'b') und polar(x2,y2,'r');
%
%    mn_polar(x1,y1,y2,'r',[0 400 -10 10],5);  entspricht: step=5,axis([0 400 -10 10]);
%                                               polar(x1,y1); und polar(y2,'r');
%
% Bentigte Module (Subroutinen); mssen sich im Verzeichnis befinden.
%    mn_zzz_polar_wnd.m ... Window callback
%    mn_zzz_polar_sld.m ... Slider callback
%
% 14.2.2002
% Piotr Majdak (piotr@majdak.com)
% Markus Noisternig (markus@noisternig.com)

    % declare globals
clear Vslider Vedit Gznr Gaxes Gstep Gyvec Gstr Gxvec Gidx Gcnr;
global Vslider Vedit Gznr Gaxes Gstep Gyvec Gstr Gxvec Gidx Gcnr;
    % set defaults
Gstep=1;
Gaxes=0;    % auto scaling
Gznr=1;      % # of polars
Gxvec=0;    % auto axing
Gxvec=cell(10,1);
Gyvec=cell(10,1);
Gstr=cell(10,1);

    % parse input parameters
Gcnr=0;
for ii=1:nargin
    cl=class(varargin{ii});
    si=size(varargin{ii});
    if strcmp(cl,'char')
        Gstr(Gcnr)={deal(varargin{ii})};
    elseif strcmp(cl,'double')
        if si(1)==1
            if si(2)==1
                Gstep=deal(varargin{ii});
            elseif si(2)==4
                Gaxes=deal(varargin{ii});
            else
                Gxvec(Gcnr+1)={deal(varargin{ii})};
            end
        else
            Gcnr=Gcnr+1;
            Gyvec(Gcnr)={deal(varargin{ii})};   % save Y/Z-matrix
            Gznr=size(Gyvec{1},2);
        end
    end
end
    % check for errors
if Gcnr==0
    disp('ERROR: couldn''t find the matrix!?');
    return;
end
    % the rest...
format compact
figure
Gidx=1;
mn_zzz_polar_wnd;

% Create Window
set(gcf,'MenuBar','none',...
   'NumberTitle','off',...
   'Name','Plot function, (c) 2001-2002 majnoi');

    % Create Slider
if Gznr == 1
    disp('only a vector found - slider disabled');
else
    Vslider=uicontrol('Style','slider',...
       'units','normalized',...
       'position',[.94 .085 .035 .85],...
       'Min',1,'Max',Gznr,...
       'SliderStep', [(1/Gznr) (5/Gznr)], ...
       'Value',Gidx,...
       'Callback','mn_zzz_polar_sld');
end

% Control Value
Vedit=uicontrol('Style','edit',...
   'Units','normalized',...
   'Position',[.8 .01 .15 .05],...
   'String',['index=', num2str((round(Gidx)*Gstep)-Gstep)]);

% Button 'Close'
cmd_close=uicontrol('Style','pushbutton',...
   'Position',[5 5 50 20],...
   'String','Close',...
   'Callback','clear Vslider Vedit Gznr Gaxes Gstep Gyvec Gstr Gxvec Gidx Gcnr; close(gcf)');

% Button 'Print'
cmd_print=uicontrol('Style','pushbutton',...
   'Position',[70 5 50 20],...
   'String','Print',...
   'Callback','print');

% Button 'Copy'
cmd_copy=uicontrol('Style','pushbutton',...
   'Position',[140 5 50 20],...
   'String','Copy',...
   'Callback','print -dbitmap');