function mn_spect(s,fs,typ,col)

% mn_spect         - show the magnitude and angle of a vector
% mn_spect(s [,fs] [, typ] [,col])
%
% Show the magnitude and angle of vector s
% optional using 2 subplots inside a figure
%
% Parameters: 
% s:    spectrum
% fs:   sampling frequency. Optional (default=44.1kHz)
% typ:  plot whole frequency range: 'w'
%       or only first half (up to fs/2): 'h'
%       Optional (default='h')
%       'a' amplitude only, plot in a existing (sub)plot
%       'p' phase only, plot in a existing (sub)plot
% col:  Color and symbol of plot (see PLOT). Optional (default='b')

% (c) 2002 Piotr Majdak, v1.2

if ~exist('fs')
    disp('fs set to 44100Hz');
    fs=44100;
elseif ischar(fs)
    typ=fs;
    fs=44100;
    disp('fs set to 44100Hz');
end
    % check for typ
if exist('typ')
    if typ=='w'
        half=0;
    elseif typ=='h'
        half=1;
    elseif typ=='a'
        half=1;
    elseif typ=='p'
        half=1;
    else
        col=typ;    % typ not given, it must be a col!
        half=1;
    end
else
    half=1;         % 'half' is default
    typ='h';
end

    % check for col
if ~exist('col')
    col='b';
end

if half
    fs=fs/2;
    ss=s(1:floor(end/2));
else
    ss=s;
end
len=length(ss);
fax=0:fs/len:fs-fs/len;
if typ ~='a' & typ ~='p'
    subplot(2,1,1);
end
if typ ~='p'
    plot(fax,20*log10(abs(ss)),col);
    ylabel('Magnitude in dB');
    grid on;
    hold on;
    set(gca,'XLimMode','manual');
    set(gca,'XLim',[0 fs]);
end
if typ ~='a' & typ ~='p'
    subplot(2,1,2);
end
if typ ~='a'
    plot(fax,180/pi*unwrap(angle(ss)),col);
    grid on;
    ylabel('Phase in degrees');
    xlabel('f in Hz');
    hold on;
    set(gca,'XLimMode','manual');
    set(gca,'XLim',[0 fs]);
end
